You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@wookie.apache.org by sc...@apache.org on 2011/09/20 11:58:55 UTC

svn commit: r1173060 - /incubator/wookie/trunk/connector/java/src-test/org/apache/wookie/tests/connector/framework/impl/TestWookieConnectorService.java

Author: scottbw
Date: Tue Sep 20 09:58:55 2011
New Revision: 1173060

URL: http://svn.apache.org/viewvc?rev=1173060&view=rev
Log:
Changed the default local Wookie server port to 8080, same as for the default configuration of the Standalone build, so as to hopefully avoid false negatives when testing. See WOOKIE-240.

Modified:
    incubator/wookie/trunk/connector/java/src-test/org/apache/wookie/tests/connector/framework/impl/TestWookieConnectorService.java

Modified: incubator/wookie/trunk/connector/java/src-test/org/apache/wookie/tests/connector/framework/impl/TestWookieConnectorService.java
URL: http://svn.apache.org/viewvc/incubator/wookie/trunk/connector/java/src-test/org/apache/wookie/tests/connector/framework/impl/TestWookieConnectorService.java?rev=1173060&r1=1173059&r2=1173060&view=diff
==============================================================================
--- incubator/wookie/trunk/connector/java/src-test/org/apache/wookie/tests/connector/framework/impl/TestWookieConnectorService.java (original)
+++ incubator/wookie/trunk/connector/java/src-test/org/apache/wookie/tests/connector/framework/impl/TestWookieConnectorService.java Tue Sep 20 09:58:55 2011
@@ -23,7 +23,7 @@ import org.apache.wookie.connector.frame
 import org.apache.wookie.connector.framework.WookieConnectorException;
 /**
  * A Wookie connector for testing purposes. It will first try to connect to
  * http;//localhost:8888/wookie and run tests against that server. If no instance
  * is running locally it will connect to http://bombax.oucs.ox.ac.uk:8888 a test
  * server hosted at the University of Oxford.
  * 
@@ -66,8 +66,8 @@ public class TestWookieConnectorService 
   public static TestWookieConnectorService getInstance() throws WookieConnectorException, MalformedURLException, IOException {
     if (instance == null) {
       try {
-        new URL("http://localhost:8888/wookie").openStream();
-        instance = new TestWookieConnectorService("http://localhost:8888/wookie", "TEST", "myshareddata");
+        new URL("http://localhost:8080/wookie").openStream();
+        instance = new TestWookieConnectorService("http://localhost:8080/wookie", "TEST", "myshareddata");
       } catch (ConnectException e) {
         // assume localhost is not running so run against bombax
         instance = new TestWookieConnectorService("http://bombax.oucs.ox.ac.uk:8888/wookie", "TEST", "myshareddata");
@@ -23,7 +23,7 @@ import org.apache.wookie.connector.frame
 /**
  * A Wookie connector for testing purposes. It will first try to connect to
- * http;//localhost:8888/wookie and run tests against that server. If no instance
+ * http;//localhost:8080/wookie and run tests against that server. If no instance
  * is running locally it will connect to http://bombax.oucs.ox.ac.uk:8888 a test
  * server hosted at the University of Oxford.